<?php
/**
 * Haine functions and definitions
 *
 * @package Haine
 */

if ( ! defined( '_S_VERSION' ) ) {
	define( '_S_VERSION', '1.5' );
}

/**
 * Sets up theme defaults and registers support for various WordPress features.
 */
function haine_setup() {

	load_theme_textdomain( 'haine', get_template_directory() . '/languages' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'title-tag' );
	add_theme_support( 'post-thumbnails' );

	register_nav_menus(
		array(
			'haine-primary-menu' => esc_html__( 'Primary', 'haine' )
		)
	);
    
    /**
	 * Add support for HTML5.
	 */
	add_theme_support( 'html5', array( 'comment-list', 'comment-form', 'search-form', 'gallery', 'caption' ) );
    
     /**
	 * Add support for custom background.
	 */
	add_theme_support(
		'custom-background',
		apply_filters(
			'haine_custom_background_args',
			array(
				'default-color' => 'ffffff',
				'default-image' => ''
			)
		)
	);

	add_theme_support( 'customize-selective-refresh-widgets' );

	/**
	 * Add support for core custom logo.
	 */
	add_theme_support( 'custom-logo', 
		array(
          'height'      => 60,
          'width'       => 400,
          'flex-height' => true,
          'flex-width'  => true,
          'header-text' => array( 'site-title', 'site-description' ),
        ) 
    );
    
    // Add support for responsive embeds.
	add_theme_support( 'responsive-embeds' );

	// Add support for block styles.
	add_theme_support( 'wp-block-styles' );

	// Add support for editor styles.
	add_theme_support( 'editor-styles' );

	// Set up the WordPress core custom background feature.
	$args = array(
	    'default-color' => 'fff',
	    'default-image' => ''
	);
	add_theme_support( 'custom-background', $args );

	// Set up the WordPress core custom header feature.
	add_theme_support( 'custom-header' );

	/*
	 * Enable support for wide alignment class for Gutenberg blocks.
	 */
	add_theme_support( 'align-wide' );

	/**
	 * Registers an editor stylesheet for the theme.
	 */
	add_editor_style( 'custom-editor-style.css' );

}
add_action( 'after_setup_theme', 'haine_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 */
function haine_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'haine_content_width', 640 );
}
add_action( 'after_setup_theme', 'haine_content_width', 0 );

/**
 * Register widget area.
 */
function haine_widgets_init() {
	register_sidebar(
		array(
			'name'          => esc_html__( 'Blog Sidebar', 'haine' ),
			'id'            => 'blog-sidebar',
			'description'   => esc_html__( 'Add widgets here.', 'haine' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>'
		)
	);

	register_sidebar(
		array(
			'name'          => esc_html__( 'Homepage Area', 'haine' ),
			'id'            => 'homepage',
			'description'   => esc_html__( 'Add widgets here.', 'haine' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s"><div class="container-fluid">',
			'after_widget'  => '</div></section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>'
		)
	);

	register_sidebar(
		array(
			'name'          => esc_html__( 'Footer', 'haine' ),
			'id'            => 'haine-footer',
			'description'   => esc_html__( 'Add widgets here.', 'haine' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s f-col relative col-lg-3 col-md-6 col-sm-6 col-12"><div class="static_all"><div class="footer-static-content"><div class="single-widget">',
			'after_widget'  => '</div></div></div></section>',
			'before_title'  => '<div class="footer-static-title"><h3 class="widget-title">',
			'after_title'   => '</h3></div>'
		)
	);
}
add_action( 'widgets_init', 'haine_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function haine_scripts() {
	wp_enqueue_style( 'haine-font-1', get_template_directory_uri() . '/assets/css/haine-font-1.css', array(), '1.5' );

	wp_enqueue_style( 'haine-font-2', get_template_directory_uri() . '/assets/css/haine-font-2.css', array(), '1.5' );

	wp_enqueue_style( 'haine-bootstrap', get_template_directory_uri() . '/assets/css/bootstrap.min.css', array(), '1.5' );

	wp_enqueue_style( 'haine-owl-theme', get_template_directory_uri() . '/assets/css/owl.theme.default.min.css', array(), '1.5' );

	wp_enqueue_style( 'haine-owl-carousel', get_template_directory_uri() . '/assets/css/owl.carousel.min.css', array(), '1.5' );

	wp_enqueue_style( 'haine-magnific-popup', get_template_directory_uri() . '/assets/css/magnific-popup.min.css', array(), '1.5' );

	wp_enqueue_style( 'haine-animate', get_template_directory_uri() . '/assets/css/animate.css', array(), '1.5' );

	wp_enqueue_style( 'haine-font-awesome', get_template_directory_uri() . '/assets/css/font-awesome.min.css', array(), '1.5' );

	wp_enqueue_style( 'haine-boxicons', get_template_directory_uri() . '/assets/css/boxicons.min.css', array(), '1.5' );

	wp_enqueue_style( 'haine-meanmenu', get_template_directory_uri() . '/assets/css/meanmenu.min.css', array(), '1.5' );

	wp_enqueue_style( 'haine-nice-select', get_template_directory_uri() . '/assets/css/nice-select.min.css', array(), '1.5' );

	wp_enqueue_style( 'haine-odometer', get_template_directory_uri() . '/assets/css/odometer.min.css', array(), '1.5' );

	wp_enqueue_style( 'haine-main', get_template_directory_uri() . '/assets/css/main.css', array(), '1.5' );

	if ( ! is_child_theme() ) {
		wp_enqueue_style( 'haine-style', get_stylesheet_uri(), array(), _S_VERSION );
    }

    wp_enqueue_style( 'haine-responsive', get_template_directory_uri() . '/assets/css/responsive.css', array(), '1.5' );

    wp_enqueue_script( 'haine-popper', get_template_directory_uri() . '/assets/js/popper.min.js', array(), _S_VERSION, true );

	wp_enqueue_script( 'haine-bootstrap', get_template_directory_uri() . '/assets/js/bootstrap.min.js', array(), _S_VERSION, true );

	wp_enqueue_script( 'haine-meanmenu', get_template_directory_uri() . '/assets/js/jquery.meanmenu.js', array(), _S_VERSION, true );

	wp_enqueue_script( 'haine-wow', get_template_directory_uri() . '/assets/js/wow.min.js', array(), _S_VERSION, true );

	wp_enqueue_script( 'haine-owl-carousel', get_template_directory_uri() . '/assets/js/owl.carousel.js', array(), _S_VERSION, true );

	wp_enqueue_script( 'haine-magnific-popup', get_template_directory_uri() . '/assets/js/magnific-popup.min.js', array(), _S_VERSION, true );

	wp_enqueue_script( 'haine-nice-select', get_template_directory_uri() . '/assets/js/jquery.nice-select.min.js', array(), _S_VERSION, true );

	wp_enqueue_script( 'haine-appear', get_template_directory_uri() . '/assets/js/jquery.appear.js', array(), _S_VERSION, true );

	wp_enqueue_script( 'haine-odometer', get_template_directory_uri() . '/assets/js/odometer.min.js', array(), _S_VERSION, true );

	wp_enqueue_script( 'haine-main', get_template_directory_uri() . '/assets/js/main.js', array(), _S_VERSION, true );

    wp_enqueue_script('jquery');

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'haine_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

/**
 * Load WooCommerce compatibility file.
 */
if ( class_exists( 'WooCommerce' ) ) {
	require get_template_directory() . '/inc/woocommerce.php';
}

/**
 * Include navwalker file.
 */
require get_template_directory() . '/inc/navwalker.php';

/**
 * Include documentation file.
 */
require get_template_directory() . '/inc/documentation.php';

/**
 * Include custom widgets.
 */
require get_template_directory() . '/inc/widgets/haine-about.php';
require get_template_directory() . '/inc/widgets/haine-contact.php';
require get_template_directory() . '/inc/widgets/haine-banner.php';

// Add support for register block style.
if ( function_exists( 'register_block_style' ) ) {
    register_block_style(
        'core/quote',
        array(
            'name'         => 'blue-quote',
            'label'        => __( 'Blue Quote', 'haine' ),
            'is_default'   => true,
            'inline_style' => '.wp-block-quote.is-style-blue-quote { color: blue; }'
        )
    );
}

// Add support for register block patterns.
function haine_register_block_pattern() {
    // Call to Action.
	register_block_pattern(
		'haine/call-to-action',
		array(
			'title'         => esc_html__( 'Call to Action', 'haine' ),
			'categories'    => array( 'haine' ),
			'viewportWidth' => 1400,
			'content'       => implode(
				'',
				array(
					'<!-- wp:group {"align":"wide","style":{"color":{"background":"#ffffff"}}} -->',
					'<div class="wp-block-group alignwide has-background" style="background-color:#ffffff"><div class="wp-block-group__inner-container"><!-- wp:group -->',
					'<div class="wp-block-group"><div class="wp-block-group__inner-container"><!-- wp:heading {"align":"center"} -->',
					'<h2 class="has-text-align-center">' . esc_html__( 'Support the Museum and Get Exclusive Offers', 'haine' ) . '</h2>',
					'<!-- /wp:heading -->',
					'<!-- wp:paragraph {"align":"center"} -->',
					'<p class="has-text-align-center">' . esc_html__( 'Members get access to exclusive exhibits and sales. Our memberships cost $99.99 and are billed annually.', 'haine' ) . '</p>',
					'<!-- /wp:paragraph -->',
					'<!-- wp:button {"align":"center","className":"is-style-outline"} -->',
					'<div class="wp-block-button aligncenter is-style-outline"><a class="wp-block-button__link" href="#">' . esc_html__( 'Become a Member', 'haine' ) . '</a></div>',
					'<!-- /wp:button --></div></div>',
					'<!-- /wp:group --></div></div>',
					'<!-- /wp:group -->',
				)
			),
		)
	);
}
add_action( 'init', 'haine_register_block_pattern' );
