<?php
/**
 * Haine Theme Customizer
 *
 * @package Haine
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function haine_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial(
			'blogname',
			array(
				'selector'        => '.site-title a',
				'render_callback' => 'haine_customize_partial_blogname',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'blogdescription',
			array(
				'selector'        => '.site-description',
				'render_callback' => 'haine_customize_partial_blogdescription',
			)
		);
	}
}
add_action( 'customize_register', 'haine_customize_register' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function haine_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function haine_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function haine_customize_preview_js() {
	wp_enqueue_script( 'haine-customizer', get_template_directory_uri() . '/assets/js/customizer.js', array( 'customize-preview' ), _S_VERSION, true );
}
add_action( 'customize_preview_init', 'haine_customize_preview_js' );

/**
 * Add options to Theme Customizer.
 */
function haine_options_customizer($new_customize) {

    $new_customize->add_section('header_section', array(
        
        'title'    => __('Header Options', 'haine'),
        'priority' => 20
    ));

    $new_customize->add_setting('hide_header_search', array(

        'default'   => false,
        'transport' => 'refresh'  
    ));

    $new_customize->add_control('hide_header_search', array(

        'label'    => __('Hide Header Search', 'haine'),
        'section'  => 'header_section',
        'type'     => 'checkbox'
    ));

    $new_customize->add_setting('search_placeholder_text', array(

        'default'   => __('Search...', 'haine'),
        'transport' => 'refresh'  
    ));

    $new_customize->add_control('search_placeholder_text', array(

        'label'    => __('Search Placeholder Text', 'haine'),
        'section'  => 'header_section', 
        'type'     => 'text'
    ));

    $new_customize->add_setting('hide_header_cart', array(

        'default'   => false,
        'transport' => 'refresh'  
    ));

    $new_customize->add_control('hide_header_cart', array(

        'label'    => __('Hide Header Cart', 'haine'),
        'section'  => 'header_section',
        'type'     => 'checkbox'
    ));

    $new_customize->add_setting('hide_header_btn', array(

        'default'   => false,
        'transport' => 'refresh'  
    ));

    $new_customize->add_control('hide_header_btn', array(

        'label'    => __('Hide Header Button', 'haine'),
        'section'  => 'header_section',
        'type'     => 'checkbox'
    ));

    $new_customize->add_setting('button_text', array(

        'default'   => __('Shop Now', 'haine'),
        'transport' => 'refresh'  
    ));

    $new_customize->add_control('button_text', array(

        'label'    => __('Button Text', 'haine'),
        'section'  => 'header_section', 
        'type'     => 'text'
    ));

    $new_customize->add_setting('button_link', array(

        'default'   => __('#', 'haine'),
        'transport' => 'refresh'  
    ));

    $new_customize->add_control('button_link', array(

        'label'    => __('Button Link', 'haine'),
        'section'  => 'header_section', 
        'type'     => 'url'
    ));

    $new_customize->add_section('footer_section', array(
        
        'title'    => __('Footer Options', 'haine')
    ));

    $new_customize->add_setting('copyright_text', array(

        'default'   => __('Copyright &copy; Haine - WPTheme. All rights reserved.', 'haine'),
        'transport' => 'refresh'  
    ));

    $new_customize->add_control('copyright_text', array(

        'label'    => __('Copyright Text', 'haine'),
        'section'  => 'footer_section', 
        'type'     => 'textarea'
    ));

    $new_customize->add_setting('payment_image', array(

        'default'   => '',
        'transport' => 'refresh'
    ));

    $new_customize->add_control(
    	new WP_Customize_Image_Control($new_customize, 'payment_image', array(
            'label'    => __('Payment Image', 'haine'),
            'section'  => 'footer_section',
            'settings' => 'payment_image'

    	))
    );
}

add_action('customize_register', 'haine_options_customizer');
