<?php

if( ! function_exists( 'haine_customize_scripts' ) ) :
/**
 * Enqueue customize scripts and styles.
*/
function haine_customize_scripts() {
	$array = array(
		'ajax_url'   => admin_url( 'admin-ajax.php' ),
		'flushit'    => __( 'Successfully Flushed!', 'haine' ),
		'nonce'      => wp_create_nonce('ajax-nonce')
	);
	wp_enqueue_style( 'haine-customize-style',get_template_directory_uri().'/inc/css/customize.css', '', _S_VERSION );
	wp_enqueue_script( 'haine-customize-js', get_template_directory_uri().'/inc/js/customize.js', array( 'jquery' ), _S_VERSION, true );
	wp_localize_script( 'haine-customize-js', 'haine_cdata', $array );
}
endif;
add_action( 'customize_controls_enqueue_scripts', 'haine_customize_scripts' );

if( ! function_exists( 'haine_admin_scripts' ) ) :
/**
 * Enqueue admin scripts and styles.
*/
function haine_admin_scripts(){
    wp_enqueue_style( 'haine-admin', get_template_directory_uri() . '/inc/css/admin.css', '', _S_VERSION );
    wp_enqueue_script( 'haine-jquery-cookie', get_template_directory_uri().'/inc/js/jquery.cookie.js', array( 'jquery' ), _S_VERSION, true );
     wp_enqueue_script( 'haine-admin', get_template_directory_uri().'/inc/js/admin.js', array( 'jquery' ), _S_VERSION, true );
}
endif; 
add_action( 'admin_enqueue_scripts', 'haine_admin_scripts' );

if( class_exists( 'WP_Customize_Section' ) ) :
/**
 * Adding Go to Pro Section in Customizer
 */
class Haine_Customize_Section_Pro extends WP_Customize_Section {

	/**
	 * The type of customize section being rendered.
	 *
	 * @since  1.0.0
	 * @access public
	 * @var    string
	 */
	public $type = 'pro-section';

	/**
	 * Custom button text to output.
	 *
	 * @since  1.0.0
	 * @access public
	 * @var    string
	 */
	public $pro_text = '';

	/**
	 * Custom pro button URL.
	 *
	 * @since  1.0.0
	 * @access public
	 * @var    string
	 */
	public $pro_url = '';

	/**
	 * Add custom parameters to pass to the JS via JSON.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function json() {
		$json = parent::json();

		$json['pro_text'] = $this->pro_text;
		$json['pro_url']  = esc_url( $this->pro_url );

		return $json;
	}

	/**
	 * Outputs the Underscore.js template.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	protected function render_template() { ?>
		<li id="accordion-section-{{ data.id }}" class="accordion-section control-section control-section-{{ data.type }} cannot-expand">
			<h3 class="accordion-section-title">
				{{ data.title }}
				<# if ( data.pro_text && data.pro_url ) { #>
					<a href="{{ data.pro_url }}" class="button button-secondary alignright" target="_blank">{{ data.pro_text }}</a>
				<# } #>
			</h3>
		</li>
	<?php }
}
endif;

add_action( 'customize_register', 'haine_sections_pro' );

function haine_sections_pro( $manager ) {
	// Register custom section types.
	$manager->register_section_type( 'Haine_Customize_Section_Pro' );

	// Register sections.
	$manager->add_section(
		new Haine_Customize_Section_Pro(
			$manager,
			'haine_view_pro',
			array(
				'title'    => esc_html__( 'Pro Available', 'haine' ),
                'priority' => 5, 
				'pro_text' => esc_html__( 'VIEW PRO THEME', 'haine' ),
				'pro_url'  => 'https://www.templatemonster.com/woocommerce-themes/haine-fashion-and-clothing-shop-woocommerce-theme-268567.html'
			)
		)
	);
}

function haine_admin_notice_pro() {
    global $pagenow;
    if ( $pagenow == 'index.php' ) { ?>
    <div class="notice haine-theme-notice notice-success first-notice is-dismissible">
        <p><?php _e( 'Pro Version Available!', 'haine' ); ?>
        	<a class="button button-primary" href="https://www.templatemonster.com/woocommerce-themes/haine-fashion-and-clothing-shop-woocommerce-theme-268567.html" target="_blank"><?php _e( 'View Pro Theme', 'haine' ); ?></a>
        	<button class="button button-secondary" target="_blank"><?php _e( "Don't Show Again", 'haine' ); ?></button>
        </p>
    </div>
    <?php  }
}


if (isset($_COOKIE['HaineFirstNotice'])) {
}
else {
    add_action( 'admin_notices', 'haine_admin_notice_pro' );
}

function haine_admin_notice_review() {
    global $pagenow;
    if ( $pagenow == 'index.php' ) { ?>
    <div class="notice haine-theme-notice notice-success second-notice is-dismissible">
        <p><?php _e( 'We accept a highest review from you.', 'haine' ); ?>
        	<a class="button button-primary" href="https://wordpress.org/support/theme/haine/reviews/#new-post" target="_blank"><?php _e( 'Review Our Theme', 'haine' ); ?></a>
        	<button class="button button-secondary" target="_blank"><?php _e( "Don't Show Again", 'haine' ); ?></button>
        </p>
    </div>
    <?php  }
} 

if (isset($_COOKIE['HaineSecondNotice'])) {
}
else {
   add_action( 'admin_notices', 'haine_admin_notice_review' );
}
